package org.apidesign.apifest08.currency;

/**
 * Conversion not suported exception. This expecption may optionaly describe which conversion was required and failed.
 * Required conversion can be found in {@link #getFromCurrecyCode() } and {@link #getToCurrecyCode() }.
 * 
 * @author arnostvalicek
 * @since version2
 */
public class ConversionNotSupportedException extends ConvertorException {
    String from;
    String to;
    boolean reversed;
    
    public ConversionNotSupportedException() {
        super();
    }

    public ConversionNotSupportedException(String message) {
        super(message);
    }

    public ConversionNotSupportedException(String message, Throwable cause) {
        super(message, cause);
    }

    public ConversionNotSupportedException(Throwable cause) {
        super(cause);
    }
    
    /**
     * Create exception witd additional information about currencies which are not supported in coversion.
     * @param from Code of source currency.
     * @param to Code of target currency.
     * @param twoWay Set to <code>false</code> if <em>From-&gt;To</em> is not supported.
     *               Set to <code>true</code> if both ways <em>From-&gt;To</em> and <em>To->From</em> conversions are not supported.
     *               
     */
    public ConversionNotSupportedException(String from, String to, boolean twoWay) {
        this.from = from;
        this.to = to;
        this.reversed = true;
    }

    @Override
    public String toString() {
        if (from!=null && to !=null) {
          if (reversed) {
             return "Neither onversion nor reverted conversion from " + from + " to " + to + "  is not supported,"; 
          }  else {
             return "Conversion from " + from + " to " + to + "  is not supported,"; 
          }
        } else {
            return super.toString();
        }
    }
    
    /**
     * Returns code of source currency. This value may be null.
     * @return Returns code of source currency.
     */
    public String getFromCurrecyCode() {
        return from;
    }

    /**
     * Returns code of target currency. This value may be null.
     * @return Returns code of target currency.
     */    public String getToCurrecyCode() {
        return to;
    }
     
    /**
     * Returns if one way of two way conversion is not supported.
     * 
     * Value <code>false</code> means one way conversion is not supported. Value <code>true</code> means
     * that two way conversio is not supported.
     * 
     * @return Returs <code>false</code> for one way conversion, <code>true</code> for two way conversion.
     */ 
    public boolean getTwoWayConversion() {
        return reversed;
    }

}
